@@ -1,7 +1,7 @@
 package DBG;
+$DBG::VERSION = '0.001';
 # ABSTRACT: A collection of debugging functions
-use version;
-our $VERSION = 'v0.4.1'; # VERSION
+
 
 use v5.10;
 use strict;
@@ -65,9 +65,10 @@ BEGIN {
 }
 
 END {
-    if ( $HEADER && $stamped ) {
+    if ($stamped) {
         my $msg = join '', "\n", '** DEBUGGING SESSION END: ', DateTime->now,
-          ' ; PID: ', $$, ' **';
+          ' ; PID: ',
+          $$, ' **';
         _tee($msg);
     }
     $fh->close if $fh;
@@ -76,7 +77,7 @@ END {
 {    # DateTime with optional label payload
 
     package DBG::ts;
-$DBG::ts::VERSION = '0.004';
+$DBG::ts::VERSION = '0.001';
 use parent 'DateTime';
     use Scalar::Util qw(refaddr);
 
@@ -287,15 +288,9 @@ sub pkg($$;$) {
 
 
 sub sz($;$) {
-    state $ts = eval { require Devel::Size };
-    if ($ts) {
-        my $msg = Devel::Size::total_size( pop @_ );
-        $msg = pop(@_) . ' ' . $msg if @_;
-        _tee($msg);
-    }
-    else {
-        _tee('sz requires Devel::Size');
-    }
+    my $msg = total_size pop @_;
+    $msg = pop(@_) . ' ' . $msg if @_;
+    _tee($msg);
 }
 
 
@@ -378,12 +373,12 @@ sub _flt {
     my $i = shift;
     return "$i" if blessed $i;
     for ( ref $i ) {
-        if ($_ eq 'HASH') {
+        when ('HASH') {
             my %h = %$i;
             $_ = _flt($_) for values %h;
             return \%h;
         }
-        elsif ($_ eq 'ARRAY') {
+        when ('ARRAY') {
             return [ map { _flt($_) } @$i ];
         }
     }
@@ -404,7 +399,7 @@ DBG - A collection of debugging functions
 
 =head1 VERSION
 
-version v0.4.1
+version 0.001
 
 =head1 SYNOPSIS
 
@@ -414,21 +409,21 @@ version v0.4.1
   ...
   dbg "log this $message";
   ...
-  png;                  # do I ever get here?
+  png;                   # do I ever get here?
   ...
-  trc;                  # how did I get here?
+  trc;                   # how did I get here?
   ...
-  dmp $obj;             # what is this?
+  dmp $obj;              # what is this?
   ...
-  cyc $obj;             # does this have reference cycles?
+  cyc $obj;              # does this have reference cycles?
   ...
-  my $ts = ts;          # get me the current time
+  my $ts = ts;           # get me the current time
   ...
-  rt $ts, ts;           # how long did that take?
+  rt $ts, ts;            # how long did that take?
   ...
-  prp "is it so", $val; # prints message plus "yes" or "no"
+  prp "is it so?", $val; # prints message plus "yes" or "no"
   ...
-  pkg $obj, 'doit';     # prints package providing obj's doit method
+  pkg $obj, 'doit';      # prints package providing obj's doit method
   ...
 
 =head1 DESCRIPTION
@@ -452,7 +447,7 @@ trying to compile the code and looking at the errors.
 All functions have short names to make debugging quick(er).
 
 All debugging messages are printed both to the screen and to a log. The log will
-be C<~/DBG.log> unless otherwise specified. See C<$ENV{DBG_LOG}>. This facilitates
+be C<~/log> unless otherwise specified. See C<$ENV{DBG_LOG}>. This facilitates
 examining debugging output at one's leisure without having to visually cull away
 any other output produced by the program.
 
@@ -627,9 +622,7 @@ as a label and the second the scalar.
   sz {};         # 128
   sz 'foo', {};  # foo 128
 
-This delegates to the C<total_size> function in L<Devel::Size>. If you do not
-have L<Devel::Size>, the C<sz> will only emit a warning that it requires
-L<Devel::Size>.
+This delegates to the C<total_size> function in L<Devel::Size>.
 
 =head2 mtd($;$) -- "method"
 
@@ -703,7 +696,7 @@ copies with flattened values. Anything blessed it stringifies.
 
   flt { bar => 1, baz => DateTime->now };
 
-  # {
+  # $VAR1 = {
   #     'bar' => 1,
   #     'baz' => '2014-05-31T21:04:07'
   # };
@@ -763,11 +756,11 @@ for screening it out:
   my $rx = qr/
     ( (?&line){0,3} (?&dbg) (?&line){0,3} )
     (?(DEFINE)
-      (?<line> ^.*?(?:\R|\z) )
-      (?<dbg>  ^\+\s*use\s+DBG\b.*?(?:\R|\z) )
+      (?<line> ^.*?(?:\R|\Z) )
+      (?<dbg>  ^\+\s*use\s+DBG\b.*?(?:\R|\Z) )
     )
   /mx;
-  my $text = `git diff --staged`;
+  my $text = `git diff HEAD`;
   if ( my @matches = $text =~ /$rx/g ) {
       @matches = grep defined, @matches;
       exit 0 unless @matches;
@@ -778,16 +771,25 @@ for screening it out:
   }
   exit 0;
 
-=head1 AUTHOR
+=head1 AUTHORS
+
+=over 4
+
+=item *
 
 Grant Street Group <developers@grantstreet.com>
 
+=item *
+
+David F. Houghton <dfhoughton@gmail.com>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2014 - 2020 by Grant Street Group.
+This software is copyright (c) 2014 by Grant Street Group.
 
-This is free software, licensed under:
-
-  The Artistic License 2.0 (GPL Compatible)
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
